"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MockPlatform = exports.mockPlatformFactory = void 0;
const __1 = require("../..");
const rpc_1 = require("./rpc");
const chain_1 = require("./chain");
const tokenBridge_1 = require("./tokenBridge");
function mockPlatformFactory(p) {
    class ConcreteMockPlatform extends MockPlatform {
        static _platform = p;
        platform = ConcreteMockPlatform._platform;
    }
    return ConcreteMockPlatform;
}
exports.mockPlatformFactory = mockPlatformFactory;
// Note: don't use this directly, instead create a ConcreteMockPlatform with the
// mockPlatformFactory
class MockPlatform {
    // @ts-ignore
    platform;
    conf;
    constructor(conf) {
        this.conf = conf;
    }
    getDecimals(chain, rpc, token) {
        throw new Error("Method not implemented.");
    }
    getBalance(chain, rpc, walletAddr, token) {
        throw new Error("Method not implemented.");
    }
    getChain(chain) {
        return new chain_1.MockChain(this, chain);
    }
    getRpc(chain) {
        // @ts-ignore
        return new rpc_1.MockRpc(chain);
    }
    async getWrappedAsset(chain, rpc, token) {
        throw new Error("Method not implemented.");
    }
    async getTokenDecimals(rpc, token) {
        return 8n;
    }
    async getNativeBalance(rpc, walletAddr) {
        return 0n;
    }
    async getTokenBalance(chain, rpc, walletAddr, token) {
        return 10n;
    }
    async parseTransaction(chain, rpc, txid) {
        throw new Error("Method not implemented");
    }
    parseAddress(chain, address) {
        if (!(0, __1.nativeIsRegistered)(chain))
            throw new Error("Chain not registered");
        //@ts-ignore
        return (0, __1.toNative)(chain, address).toUniversalAddress();
    }
    async sendWait(chain, rpc, stxns) {
        throw new Error("Method not implemented.");
    }
    async getWormholeCore(rpc) {
        throw new Error("Method not implemented.");
    }
    async getTokenBridge(rpc) {
        // @ts-ignore
        return new tokenBridge_1.MockTokenBridge(rpc);
    }
    async getAutomaticTokenBridge(rpc) {
        throw new Error("Method not implemented.");
    }
    async getCircleBridge(rpc) {
        throw new Error("Method not implemented.");
    }
    async getCircleRelayer(rpc) {
        throw new Error("Method Not implemented.");
    }
    async getAutomaticCircleBridge(rpc) {
        throw new Error("Method not implemented.");
    }
}
exports.MockPlatform = MockPlatform;
//# sourceMappingURL=platform.js.map