import { ChainName, PlatformName } from "@wormhole-foundation/sdk-base";
import { Platform } from "./platform";
import { RpcConnection } from "./rpc";
import { AutomaticTokenBridge, TokenBridge } from "./protocols/tokenBridge";
import { AutomaticCircleBridge, CircleBridge } from "./protocols/cctp";
type _omitChain<Fn> = Fn extends (chain: ChainName, ...args: infer A) => infer R ? (...args: A) => R : Fn;
type _omitRpc<P extends PlatformName, Fn> = Fn extends (rpc: RpcConnection<P>, ...args: infer A) => infer R ? (...args: A) => R : Fn;
type OmitChainRpc<P extends PlatformName, F extends keyof Platform<P>> = _omitRpc<P, _omitChain<Platform<P>[F]>>;
type OmitRpc<P extends PlatformName, F extends keyof Platform<P>> = _omitRpc<P, Platform<P>[F]>;
type OmitChain<P extends PlatformName, F extends keyof Platform<P>> = _omitChain<Platform<P>[F]>;
export declare abstract class ChainContext<P extends PlatformName> {
    readonly platform: Platform<P>;
    readonly chain: ChainName;
    protected tokenBridge?: TokenBridge<P>;
    protected autoTokenBridge?: AutomaticTokenBridge<P>;
    protected circleBridge?: CircleBridge<P>;
    protected autoCircleBridge?: AutomaticCircleBridge<P>;
    constructor(platform: Platform<P>, chain: ChainName);
    abstract getRpc(): RpcConnection<P>;
    getDecimals: OmitChainRpc<P, "getDecimals">;
    getBalance: OmitChainRpc<P, "getBalance">;
    parseTransaction: OmitChainRpc<P, "parseTransaction">;
    sendWait: OmitChainRpc<P, "sendWait">;
    parseAddress: OmitChain<P, "parseAddress">;
    getTokenBridge: OmitRpc<P, "getTokenBridge">;
    getAutomaticTokenBridge: OmitRpc<P, "getAutomaticTokenBridge">;
    getCircleBridge: OmitRpc<P, "getCircleBridge">;
    getAutomaticCircleBridge: OmitRpc<P, "getAutomaticCircleBridge">;
}
export {};
//# sourceMappingURL=chain.d.ts.map